==> prestashop_1.5.6.2.zip: prestashop/CONTRIBUTORS.md <==
	- (d)oekia
	- Agence CINS
	- Aleksander Palyan
	- Alexander Otchenashev
	- Andrew
	- AntonLejon
	- Arnaud Lemercier
	- Axome
	- Benjamin PONGY
	- BigZ
	- Burhan
	- CINS
	- Caleydon Media
	- Captain FLAM
	- Captain-FLAM
	- Chris
	- ChristopheBoucaut
	- Corentin Delcourt
	- Cosmin Hutanu
	- Cédric Mouleyre
	- Damien Metzger
	- DamienMetzger
	- Damon Skelhorn
	- Daniel
	- Daniele Giachino
	- David Gasperoni
	- Davy Rolink
	- Dinis Lage
	- Dragan Skrbic
	- DrySs
	- DrÿSs
	- DrÿSs'
	- Edouard Gaulué
	- Eric Le Lay
	- Fabio Chelly
	- Francois Gaillard
	- François Gaillard
	- Franois Gaillard
	- Frédéric BENOIST
	- Gabriel Schwardy
	- Gaelle ITZKOVITZ
	- Gamesh
	- Gregory Roussac
	- Grégoire Bélorgey
	- Guillaume DELOINCE
	- Ha!*!*y
	- Javsmile
	- Jeroen Dewaele
	- Jerome Nadaud
	- Jonathan Danse
	- Julien
	- Jáchym Toušek
	- Jérôme Nadaud
	- Kevin Granger
	- Krystian Podemski
	- LOIC ROSSET ltd
	- Madef
	- Mainmich
	- Marco Cervellin
	- Mats Rynge
	- MatthieuB
	- Maxence
	- Michel Courtade
	- Mickael Desgranges
	- Mikael Blotin
	- Milow
	- MustangZhong
	- Nicolas Sorosac
	- Nils-Helge Garli Hegvik
	- Nino Uzelac
	- Otto Nascarella
	- Patanock
	- PhpMadman
	- Pierre
	- Piotr Kaczor
	- Piotr Moćko
	- PrestaEdit
	- PrestaLab
	- PrestanceDesign
	- Prestaspirit
	- Priyank Bolia
	- Quentin Montant
	- Raphaël Malié
	- Rimas Kudelis
	- Rémi Gaillard
	- Samy Rabih
	- Sarah Lorenzini
	- Seb
	- Seynaeve
	- Shagshag
	- Staging
	- Sylvain Gougouzian
	- Sylvain WITMEYER
	- Sébastien
	- Sébastien Bocahu
	- Tom Panier
	- Tomasz Slominski
	- Vincent Augagneur
	- Vincent Schoener
	- Vincent Terenti
	- Xavier
	- Xavier POITAU
	- Yoozio
	- Zollner Robert
	- aFolletete
	- aKorczak
	- aNiassy
	- adonis karavokyros
	- anat
	- antoniofr
	- bLeveque
	- bMancone
	- bumbu
	- cam.lafit
	- ccauw
	- cedricfontaine
	- cippest
	- cmouleyre
	- dMetzger
	- dSevere
	- djfm
	- dlage
	- dreammeup
	- emily-d
	- fBrignoli
	- fSerny
	- fchellypresta
	- fram
	- gBrunier
	- gCharmes
	- gPoulain
	- gRoussac
	- gr4devel
	- hAitmansour
	- ha99y
	- indesign47
	- inem0o
	- ivancasasempere
	- jBreux
	- jObregon
	- jeckyl
	- jeromenadaud
	- jessylenne
	- jmCollin
	- joseantgv
	- kiropowered
	- kpodemski
	- lBrieu
	- lCherifi
	- lLefevre
	- ldecoker
	- mBertholino
	- mDeflotte
	- mMarinetti
	- makk1ntosh
	- marcinsz101
	- matiasiglesias
	- minic studio
	- misthero
	- montes
	- nPellicari
	- nezenmoins
	- nturato
	- oleacorner
	- prestamodule
	- prestarocket
	- pxls
	- rGaillard
	- rMalie
	- rMontagne
	- raulgundin
	- romainberger
	- root
	- runningz
	- sLorenzini
	- sThiebaut
	- sagaradonis
	- sjousse
	- smartdatasoft
	- soufyan
	- soware
	- tDidierjean
	- thoma202
	- tucoinfo
	- unknown
	- vAugagneur
	- vChabot
	- vKham
	- vSchoener
	- vinvin27
	- zimmi1

==> prestashop_1.5.6.3.zip: prestashop/CONTRIBUTORS.md <==
	- Agence CINS
	- Aleksander Palyan
	- Andrew
	- Axome
	- BigZ
	- CINS
	- Captain FLAM
	- Captain-FLAM
	- Chris
	- ChristopheBoucaut
	- Corentin Delcourt
	- Cosmin Hutanu
	- Damien Metzger
	- Daniel
	- Daniele Giachino
	- Davy Rolink
	- Dinis Lage
	- Eric Le Lay
	- Fabio Chelly
	- Francois Gaillard
	- François Gaillard
	- Frédéric BENOIST
	- Gaelle ITZKOVITZ
	- Gamesh
	- Gregory Roussac
	- Grégoire Bélorgey
	- Guillaume DELOINCE
	- Javsmile
	- Jeroen Dewaele
	- Jerome Nadaud
	- Julien
	- Jáchym Toušek
	- Jérôme Nadaud
	- Kevin Granger
	- Krystian Podemski
	- LOIC ROSSET ltd
	- Madef
	- Mainmich
	- MatthieuB
	- Maxence
	- Mickael Desgranges
	- Mikael Blotin
	- MustangZhong
	- Nicolas Sorosac
	- Nils-Helge Garli Hegvik
	- Nino Uzelac
	- PhpMadman
	- Piotr Kaczor
	- Piotr Moćko
	- PrestaEdit
	- PrestaLab
	- PrestanceDesign
	- Prestaspirit
	- Priyank Bolia
	- Quentin Montant
	- Rimas Kudelis
	- Rémi Gaillard
	- Samy Rabih
	- Sarah Lorenzini
	- Seb
	- Seynaeve
	- Shagshag
	- Staging
	- Sylvain Gougouzian
	- Sylvain WITMEYER
	- Sébastien
	- Thomas Nabord
	- Tom Panier
	- Tomasz Slominski
	- Vincent Augagneur
	- Xavier
	- Yoozio
	- Zollner Robert
	- antoniofr
	- axi
	- cam.lafit
	- ccauw
	- cedricfontaine
	- cippest
	- djfm
	- dlage
	- dreammeup
	- emily-d
	- fchellypresta
	- fram
	- gRoussac
	- gr4devel
	- ha99y
	- indesign47
	- inem0o
	- jeckyl
	- jeromenadaud
	- joseantgv
	- kiropowered
	- ldecoker
	- makk1ntosh
	- matiasiglesias
	- misthero
	- prestamodule
	- rGaillard
	- romainberger
	- runningz
	- sLorenzini
	- sagaradonis
	- sjousse
	- smartdatasoft
	- soufyan
	- soware
	- thoma202
	- tucoinfo
	- unknown
	- vinvin27
	- zimmi1
